#[non_exhaustive]pub struct NetworkConfig {
pub network: String,
pub ip_allocation: String,
/* private fields */
}Expand description
Network configuration for a Data Fusion instance. These configurations are used for peering with the customer network. Configurations are optional when a public Data Fusion instance is to be created. However, providing these configurations allows several benefits, such as reduced network latency while accessing the customer resources from managed Data Fusion instance nodes, as well as access to the customer on-prem resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.network: StringName of the network in the customer project with which the Tenant Project will be peered for executing pipelines. In case of shared VPC where the network resides in another host project the network should specified in the form of projects/{host-project-id}/global/networks/{network}
ip_allocation: StringThe IP range in CIDR notation to use for the managed Data Fusion instance nodes. This range must not overlap with any other ranges used in the customer network.
Implementations
Sourceimpl NetworkConfig
impl NetworkConfig
Sourcepub fn set_network<T: Into<String>>(self, v: T) -> Self
pub fn set_network<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_ip_allocation<T: Into<String>>(self, v: T) -> Self
pub fn set_ip_allocation<T: Into<String>>(self, v: T) -> Self
Sets the value of ip_allocation.
Example
let x = NetworkConfig::new().set_ip_allocation("example");Trait Implementations
Sourceimpl Clone for NetworkConfig
impl Clone for NetworkConfig
Sourcefn clone(&self) -> NetworkConfig
fn clone(&self) -> NetworkConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NetworkConfig
impl Debug for NetworkConfig
Sourceimpl Default for NetworkConfig
impl Default for NetworkConfig
Sourcefn default() -> NetworkConfig
fn default() -> NetworkConfig
Sourceimpl Message for NetworkConfig
impl Message for NetworkConfig
Sourceimpl PartialEq for NetworkConfig
impl PartialEq for NetworkConfig
impl StructuralPartialEq for NetworkConfig