#[non_exhaustive]pub struct UpdateInstanceRequest {
pub instance: Option<Instance>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for updating a Data Fusion instance. Data Fusion allows updating the labels, options, and stack driver settings. This is also used for CDF version upgrade.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance: Option<Instance>Required. The instance resource that replaces the resource on the server. Currently, Data Fusion only allows replacing labels, options, and stack driver settings. All other fields will be ignored.
update_mask: Option<FieldMask>Field mask is used to specify the fields that the update will overwrite in an instance resource. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask, all the supported fields (labels, options, and version currently) will be overwritten.
Implementations
Sourceimpl UpdateInstanceRequest
impl UpdateInstanceRequest
Sourcepub fn set_instance<T>(self, v: T) -> Self
pub fn set_instance<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_instance<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_instance<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateInstanceRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateInstanceRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateInstanceRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateInstanceRequest
impl Clone for UpdateInstanceRequest
Sourcefn clone(&self) -> UpdateInstanceRequest
fn clone(&self) -> UpdateInstanceRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateInstanceRequest
impl Debug for UpdateInstanceRequest
Sourceimpl Default for UpdateInstanceRequest
impl Default for UpdateInstanceRequest
Sourcefn default() -> UpdateInstanceRequest
fn default() -> UpdateInstanceRequest
Sourceimpl Message for UpdateInstanceRequest
impl Message for UpdateInstanceRequest
Sourceimpl PartialEq for UpdateInstanceRequest
impl PartialEq for UpdateInstanceRequest
impl StructuralPartialEq for UpdateInstanceRequest